@@ -28,13 +28,32 @@ def tox_configure(config):
     envlist = get_envlist_from_factors(config.envlist, factors)
     verbosity2("new envlist: {}".format(envlist))
 
-    if "GITHUB_ACTION" not in os.environ:
+    if not is_running_on_actions():
         verbosity1("tox is not running in GitHub Actions")
         verbosity1("tox-gh-actions won't override envlist")
         return
+    elif is_env_specified(config):
+        verbosity1("envlist is explicitly given via TOXENV or -e option")
+        verbosity1("tox-gh-actions won't override envlist")
+        return
+
     config.envlist_default = config.envlist = envlist
 
 
+@hookimpl
+def tox_runtest_pre(venv):
+    # type: (Any) -> None
+    if is_running_on_actions():
+        print("::group::tox: " + venv.name)
+
+
+@hookimpl
+def tox_runtest_post(venv):
+    # type: (Any) -> None
+    if is_running_on_actions():
+        print("::endgroup::")
+
+
 def parse_config(config):
     # type: (Dict[str, Dict[str, str]]) -> Dict[str, Dict[str, Any]]
     """Parse gh-actions section in tox.ini"""
@@ -91,6 +110,26 @@ def get_python_version():
     return '.'.join([str(i) for i in sys.version_info[:2]])
 
 
+def is_running_on_actions():
+    # type: () -> bool
+    """Returns True when running on GitHub Actions"""
+    # See the following document on which environ to use for this purpose.
+    # https://docs.github.com/en/free-pro-team@latest/actions/reference/environment-variables#default-environment-variables
+    return os.environ.get("GITHUB_ACTIONS") == "true"
+
+
+def is_env_specified(config):
+    # type: (Config) -> None
+    """Returns True when environments are explicitly given"""
+    if os.environ.get("TOXENV"):
+        # When TOXENV is a non-empty string
+        return True
+    elif config.option.env is not None:
+        # When command line argument (-e) is given
+        return True
+    return False
+
+
 # The following function was copied from
 # https://github.com/tox-dev/tox-travis/blob/0.12/src/tox_travis/utils.py#L11-L32
 # which is licensed under MIT LICENSE
